@@ -9,7 +9,7 @@ import sys
 from difflib import SequenceMatcher
 from enum import Enum
 
-__version__ = "0.0.22"
+__version__ = "0.0.24"
 
 from typing import Optional, List, Iterable
 
@@ -374,7 +374,7 @@ class CheckParser:
                     LINE_NUMBER_REGEX,
                     str(line_idx + offset + 1),
                     check_expression,
-                    1,
+                    count=1,
                 )
                 line_var_match = re.search(LINE_NUMBER_REGEX, check_expression)
 
